# Sigma Coding Python Library

## Table of Contents

- [Overview](#overview)
- [Setup](#setup)
- [Usage](#usage)
- [Support These Projects](#support-these-projects)

## Overview
A GUI that can plot spectroscopy data, perform post-processing and save data for later reference. 
## Setup
How to Install the GUI:
Create a virtual environment (requires python 3 or greater)
::
	python -m venv <desired file path here>

Activate the virtual environment
::
	source <desired file path here>/bin/activate

Install the package onto the system (requires python verion 3 or greater)
::
	pip install MAST-U-DMS-GUI


This result in the package being installed on this virtual environment in the desired file path.

## Usage
Once installed, these commands can be run within the virtual environment.
::
	Run_MAST-U_DMS_GUI

Runs the main GUI for loading and processing data.

::
	Run_MAST-U_DMS_saved_data_plotter

Runs the GUI that can load in saved data plots.

